/*
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM
 *
 * com.ibm.rational.wvcm.stp.cc.CcFindmergeListener
 *
 * (C) Copyright IBM Corporation 2012.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */
package com.ibm.rational.wvcm.stp.cc;


/**
 * Interface that extends the basic CcListener class. This is used for specific
 * CCRC CLI related callbacks for Update operations.
 */
public interface CcUpdateListener extends CcListener {

    /**
     * Callback from response handler to notify that a file or directory is 
     * updated and update type is associated with it.
     * @param updateType update type for this file or directory @see UpdateType
     * @param file The CcFile is representing the updated file or directory.
     */
    public void notifyUpdate (UpdateType updateType, CcFile file);    

    /** Values for file or directory update type */
    public enum UpdateType {
        /**
         * Update found for this file or directory 
         */
        CANDIDATE_FOUND,
        
        /**
         * Checkout found for this file or direcotry
         */
        CHECKOUT_FOUND,
        
        /**
         * Kept hijack this file or direcotry
         */
        KEPT_HIJACK,
        
        /**
         * Loaded this file or directory
         */
        LOADED,
        
        /**
         * Reloaded this file or directory
         */
        RELOADED,
        
        /**
         * Restored this file or directory
         */
        RESTORED,
        
        /**
         * Unloaded this file or directory
         */
        UNLOADED,
        
        /**
         * Cancelled hijack for this file or directory
         */
        UNDID_HIJACK,
        
        /**
         * Updated this file or directory
         */
        UPDATED;
    }
}

